package com.joinmassive.sampleapp

import android.content.Context
import android.os.Build
import android.text.Html
import android.text.method.LinkMovementMethod
import android.view.LayoutInflater
import android.widget.Button
import android.widget.TextView
import androidx.appcompat.app.AlertDialog

class ConsentHelper(private val prefsName: String, private val context: Context) {
    fun showConsentDialog(onAccept: () -> Unit, onDecline: () -> Unit) {
        val dialogView = LayoutInflater.from(context).inflate(R.layout.dialog_consent, null)
        val tvConsentText = dialogView.findViewById<TextView>(R.id.tvConsentText)

        val faqText = context.getString(R.string.href_massive_faq)
        val licenseText = context.getString(R.string.href_massive_license)
        val privacyText = context.getString(R.string.href_privacy_policy)

        val consentTextFormatted = context.getString(R.string.text_consent, faqText, licenseText, privacyText)
        val spannedConsentText = if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.N) {
            Html.fromHtml(consentTextFormatted, Html.FROM_HTML_MODE_COMPACT)
        } else {
            @Suppress("DEPRECATION")
            Html.fromHtml(consentTextFormatted)
        }

        tvConsentText.movementMethod = LinkMovementMethod.getInstance()
        tvConsentText.text = spannedConsentText


        val dialog = AlertDialog.Builder(context)
            .setView(dialogView)
            .create()

        val btnAccept = dialogView.findViewById<Button>(R.id.btnAccept)
        val btnDecline = dialogView.findViewById<Button>(R.id.btnDecline)

        btnAccept.setOnClickListener {
            // User accepted, store this in preferences and proceed
            storeConsent(true)

            onAccept()

            dialog.dismiss()
        }

        btnDecline.setOnClickListener {
            onDecline()
            dialog.dismiss()
        }

        dialog.show()
        btnAccept.requestFocus() // Set focus to the Accept button
    }

    fun isConsentGiven(): Boolean {
        val sharedPref = context.getSharedPreferences(prefsName, Context.MODE_PRIVATE)
        return sharedPref.getBoolean("ConsentGiven", false)
    }

    fun revokeConsent() {
        storeConsent(false)
    }

    private fun storeConsent(value: Boolean) {
        val sharedPref = context.getSharedPreferences(prefsName, Context.MODE_PRIVATE)
        with(sharedPref.edit()) {
            putBoolean("ConsentGiven", value)
            apply()
        }
    }
}
